
/*--------------------------------------------------------------
 | SAS Global Forum 2016 Sample
 | The GEOCODE Procedure and SAS Visual Analytics   
 |    
 | NAME:  UKPostalCode.sas
 | PURPOSE: Geocode Great Britain locations by postcode 
 |          using ZIP method.
 | PAPER: The GEOCODE Procedure and SAS Visual Analytics
 | DATE:  16Jan2016 
 +-------------------------------------------------------------*/

/**** Location where results is stored ****/
libname geo '.';

/*------------------------------------------------------------+
 |               [  Address Data  ]
 | Create data set of auto dealerships in Great Britain
 | to geocode by Royal Mail postcode.
 +------------------------------------------------------------*/
data dealers (label='Aston Martin dealers in Great Britain');
  infile datalines dlm=',';
  length name $50 postcode $10 city borough $32 country $2;
  input name postcode city borough country;
  label name     = 'Dealership' 
        postcode = 'Royal Mail postcode'
        city     = 'City'
        borough  = 'Borough/county'
        country  = 'Country ID';
  name     = propcase(name);
  postcode = compress(postcode);
datalines;
GRANGE OF EXETER, EX2 8LB, EXETER, DEVON, UK
HARWOOD ASTON MARTIN, BN7 2NN, LEWES, EAST SUSSIX, UK
LANCASTER READING, RG2 0QX, READING, BERKSHIRE, UK
HWM ASTON MARTIN, KT12 1AT, WALTON-ON-THAMES, SURREY, UK
LANCASTER, TN13 2DN, SEVENOAKS, KENT, UK
GRANGE ASTON MARTIN, CM14 5LU, BRENTWOOD, ESSEX, UK
GRANGE WELWYN, AL8 7TQ, WELWYN GARDEN CITY, HERTFORDSHIRE, UK
STRATSTONE ASTON MARTIN AMERSHAM, HP6 6AJ, AMERSHAM, BUCKINGHAMSHIRE, UK
STRATSTONE ASTON MARTIN MAYFAIR, W1K7AJ, WESTMINSTER, LONDON, UK
STRATSTONE ASTON MARTIN MAYFAIR, W30TE, LONDON, LONDON, UK
BROUGHTONS ASTON MARTIN, GL51 9TU, CHELTENHAM, GLOUCESTERSHIRE, UK
LANCASTER CAMBRIDGE, CB22 7TN, HARSTON, CAMBRIDGESHIRE, UK
STRATSTONE ASTON MARTIN HAGLEY, DY9 0QL, HAGLEY, WORCESTERSHIRE, UK
STRATSTONE ASTON MARTIN DERBY, DE21 4LT, DERBY, DERBYSHIRE, UK
STRATSTONE OF WILMSLOW, SK9 5BQ, WILMSLOW, CHESHIRE, UK
JCT 600 ASTON MARTIN BROOKLANDS, LS12 6AA, BROOKLANDS, LEEDS, UK
;

run;

/*------------------------------------------------------------+
 |                 [  Lookup Data  ]
 | The lookup data for this example is not shipped with SAS
 | You will have to download the Code-Point Open product from
 | the British Ordnance Survey (OS) and then import it with 
 | the %CODEPOINT2GEOCODE macro program. The macro program 
 | and usage instructions are in the CodePoint2Geocode.zip  
 | file on the SAS MapsOnline web site:
 |   http://support.sas.com/rnd/datavisualization/mapsonline/html/geocode.html
 | Then modify the following libname statement to the
 | LOOKUP library to specify the location where the 
 | %CODEPOINT2GEOCODE macro installed the British postcode
 | lookup data on your system. 
 +------------------------------------------------------------*/
libname LOOKUP '<path to Great Britt POSTCODES lookup data>';

/*------------------------------------------------------------+
 |                 [  Proc GEOCODE  ]
 | Use the ZIP method to determine British locations using
 | Royal Mail postcodes.
 +------------------------------------------------------------+
 |                    [  Notes  ]
 | 1. This uses the British lookup data set lookup.postcodes
 |    as described above.
 | 2. Several non-default variable names are used in the 
 |    address and lookup data sets which must be specified 
 |    with options such as ADDRESSZIPVAR and LOOKUPZIPVAR.
 | 3. ADDRESSCITYVAR, ADDRESSCOUNTRYVAR and ADDRESSCOUNTRYVAR
 |    are used so any dealerships not found by postal code will  
 |    invoke the CITY geocoding method. Since the addresses 
 |    are not in the US, those variables are required.
 |    If an observation cascades from ZIP to CITY geocoding,
 |    MAPSGFK.WORLD_CITIES is the default international city
 |    lookup data set.
 | 4. If your British lookup data was created using an older 
 |    version of %CODEPOINT2GEOCODE, the latitude and longitude
 |    vars for the WGS84 datum may be LAT_WGS84_DD and 
 |    LON_WGS84_DD. If so, add these options to the syntax:
 |       lookupxvar = LON_WGS84_DD
 |       lookupyvar = LAT_WGS84_DD
 |    If your WGS84 lookup vars are X and Y, you do not need
 |    to specify them as those are the default var names.
 +------------------------------------------------------------*/
proc geocode
   method            = zip              /* ZIP method for postcodes  */
   data              = dealers          /* Address data to geocode   */
   out               = geo.UKpostCodes  /* Geocoded output data set  */
   lookup            = lookup.GBPOSTCODES  /* GB postcode lookup data   */
   addresszipvar     = postcode         /* Address data postcode var */
   addresscityvar    = city             /* Address data city var     */
   addressstatevar   = borough          /* Address data county var   */
   addresscountryvar = country          /* Address data country var  */
   lookupzipvar      = pc;              /* Lookup data postcode var  */
run;
quit;


/* In VA, Choose Category: ID->Geography->Custom */

