

/*------------------------------------------------------------+
 | SAS Global Forum 2016 Sample
 | The GEOCODE Procedure and SAS Visual Analytics        
 |  
 |    NAME: USStreetLevel.sas  
 | SUMMARY: Geocode US locations using STREET method.
 | CAUTION: STREET geocoding lookup data set format varies 
 |          depending on your SAS release. Use the format
 |          for your SAS release.
 | PRODUCT: GRAPH
 |   PAPER: The GEOCODE Procedure and SAS Visual Analytics
 |    DATE: 29Nov2015
 +------------------------------------------------------------*/

/**** Location where results is stored ****/
libname geo '.';

/*------------------------------------------------------------+
 | Create Address data (input).
 | Create a data set of Wake County, NC schools to geocode.
 | Note that only a small subset of schools is used in example
 +------------------------------------------------------------*/
data schools (label='Wake County, NC public schools');
  infile datalines dlm=',';
  length school $64 address $32 city $24
         state $2 zip 5 type $12 color $10;
  input school address city state zip type enrollment;
datalines;
Adams Elementary, 805 Cary Towne Blvd., Cary, NC, 27511, Elementary, 770
Apex Elementary, 700 Tingen Road, Apex, NC, 27502, Elementary, 674
Apex High, 1501 Laura Duncan Road, Apex, NC, 27502, High, 2542
Apex Middle, 400 E. Moore Street, Apex, NC, 27502, Middle, 1150
Athens Drive High, 1420 Athens Drive, Raleigh, NC, 27606, High, 1943
Aversboro Elementary, 1605 Aversboro Road, Garner, NC, 27529, Elementary, 545
Broughton High, 723 St. Mary's Street, Raleigh, NC, 27605, High, 2146
Bugg Elementary, 825 Cooper Road, Raleigh, NC, 27610, Elementary, 570
Carnage Middle, 1425 Carnage Drive, Raleigh, NC, 27610, Middle, 1218
Carpenter Elementary, 2100 Morrisville Parkway, Cary, NC, 27519, Elementary, 702
Carroll Middle, 4520 Six Forks Road, Raleigh, NC, 27609, Middle, 843
;
run;

/*------------------------------------------------------------+
 | Lookup data set.
 | This example uses the SASHELP.GEOEXM data set which is 
 | installed with GRAPH. That is sample street method lookup
 | data for Wake County, NC created from U.S. Census TIGER
 | shapefiles.  This is a subset of the full lookup data set.
 +------------------------------------------------------------+
 | NOTES:
 | Street lookup data for geocoding in other U.S. counties 
 | is also available:
 | 1. Download the nationwide U.S. street lookup data  
 |    from the MapsOnLine website. That data includes the 
 |    TIGER/Line files for all of the U.S. states and
 |    overseas territories in SAS data sets and
 |    formatted for use with PROC GEOCODE:  
 |        
http://support.sas.com/rnd/datavisualization/mapsonline/html/geocode.html
 |    The format of the street lookup data changed in 
 |    SAS 9.4, so be careful to download the appropriate  
 |    U.S. lookup data for your SAS release. 
 | 2. Download the TIGER2GEOCODE.zip file which contains the
 |    SAS macro program %TIGER2GEOCODE. You can then download
 |    free TIGER files for specific counties from the 
 |    Census Bureau's TIGER shapefiles web site and use
 |    the %TIGER2GEOCODE macro to create the PROC GEOCODE
 |    street lookup data for that region. Instructions for 
 |    the %TIGER2GEOCODE macro program are in the zip file.
 +------------------------------------------------------------*/


/*------------------------------------------------------------+
 | Run Proc GEOCODE.
 | Use the STREET method to determine school locations.
 | Create the geocoded output data set: work.geocoded
 +------------------------------------------------------------+
 | NOTES:
 | 1. This uses the SASHELP.GEOEXM lookup data set as 
 |    noted above since all the addresses to geocode are
 |    within Wake County, North Carolina.
 | 2. Because the address and lookup data sets use default
 |    variable names, options such as ADDRESSCITYVAR= 
 |    and LOOKUPCITYVAR= are not needed.
 | 3. This example adds the Census tract value from the 
 |    lookup dataset with the ATTRIBUTEVAR= option. The Census
 |    tract variable name can vary depending on the release 
 |    year of the Census TIGER/Line data. The street method
 |    attribute variables are in the secondary lookup data set
 |    which has an 'S' as the last character in the name.
 |    For exampel, if the primary lookup data set is 
 |    SASHELP.GEOEXM, the secondary lookup data set is
 |    SASHELP.GEOEXS.
 +------------------------------------------------------------*/
proc geocode
   method       = street         /* Street method             */
   data         = work.schools   /* Address data to geocode   */
   out          = geo.streetlevel  /* Geocoded output data set  */
   lookupstreet = sashelp.geoexm /* Street method lookup data */   
   /*lookupstreet = sashelp.usm*/

   ;    
run;
quit;
/* In VA, Choose Category: ID->Geography->Custom */
